From mboxrd@z Thu Jan  1 00:00:00 1970
From: Kusoneko <kusoneko@kusoneko.moe>
To: list@causal.agency
Cc: Kusoneko <kusoneko@kusoneko.moe>
Subject: [PATCH] OpenBSD: switch ports MASTER_SITES=>SITES for 7.4
Date: Wed, 20 Mar 2024 22:34:02 -0400
Message-ID: <20240321023401.2431134-2-kusoneko@kusoneko.moe>
MIME-Version: 1.0
Content-Transfer-Encoding: 8bit

As of OpenBSD 7.4, ports give errors when using the following paradigm:
```
DISTFILES = file.ext:0 file2.ext:1
MASTER_SITES0 = https://asite.com/path/to/file.ext
MASTER_SITES1 = https://anothersite.com/path/to/file2.ext
```

Instead, ports now use the following:
```
DISTFILES = file.ext
DISTFILES.substring = file2.ext
SITES = https://asite.com/path/to/file.ext
SITES.substring = https://anothersite.com/path/to/file2.ext
```

This changes all the OpenBSD ports to the new paradigm, allowing them to
compile on OpenBSD 7.4+.

Note: some OpenBSD ports are not currently up to date with upstream:
- cgit-pink uses git 2.36.1 when the latest git release is 2.44.0 as of now
- litterbox is at version 1.8 instead of 1.9
- pounce* are at version 3.0 instead of 3.1
- offers catsit instead of kitd

Signed-off-by: Kusoneko <kusoneko@kusoneko.moe>
---
 OpenBSD/net/bubger/Makefile         | 2 +-
 OpenBSD/net/litterbox/Makefile      | 2 +-
 OpenBSD/net/pounce-notify/Makefile  | 2 +-
 OpenBSD/net/pounce-palaver/Makefile | 2 +-
 OpenBSD/net/pounce/Makefile         | 2 +-
 OpenBSD/sysutils/catsit/Makefile    | 2 +-
 OpenBSD/www/cgit-pink/Makefile      | 8 ++++----
 7 files changed, 10 insertions(+), 10 deletions(-)

diff --git a/OpenBSD/net/bubger/Makefile b/OpenBSD/net/bubger/Makefile
index d226626..69a8e74 100644
--- a/OpenBSD/net/bubger/Makefile
+++ b/OpenBSD/net/bubger/Makefile
@@ -15,7 +15,7 @@ PERMIT_PACKAGE =	Yes
 WANTLIB += c tls
 LIB_DEPENDS =	converters/libiconv

-MASTER_SITES =		https://git.causal.agency/bubger/snapshot/
+SITES =		https://git.causal.agency/bubger/snapshot/

 # C11
 COMPILER =		base-clang ports-gcc
diff --git a/OpenBSD/net/litterbox/Makefile b/OpenBSD/net/litterbox/Makefile
index d82b5fd..6a9f64a 100644
--- a/OpenBSD/net/litterbox/Makefile
+++ b/OpenBSD/net/litterbox/Makefile
@@ -12,7 +12,7 @@ PERMIT_PACKAGE =	Yes
 WANTLIB =		c sqlite3 tls
 LIB_DEPENDS =	databases/sqlite3

-MASTER_SITES =		https://git.causal.agency/litterbox/snapshot/
+SITES =		https://git.causal.agency/litterbox/snapshot/

 # C11
 COMPILER =	base-clang ports-gcc
diff --git a/OpenBSD/net/pounce-notify/Makefile b/OpenBSD/net/pounce-notify/Makefile
index f472957..b1d9bf7 100644
--- a/OpenBSD/net/pounce-notify/Makefile
+++ b/OpenBSD/net/pounce-notify/Makefile
@@ -16,7 +16,7 @@ PERMIT_PACKAGE =	Yes
 # uses pledge() and unveil()
 WANTLIB += c tls

-MASTER_SITES =		https://git.causal.agency/pounce/snapshot/
+SITES =		https://git.causal.agency/pounce/snapshot/

 # C11
 COMPILER =		base-clang ports-gcc
diff --git a/OpenBSD/net/pounce-palaver/Makefile b/OpenBSD/net/pounce-palaver/Makefile
index f7c10a2..e3e9d8f 100644
--- a/OpenBSD/net/pounce-palaver/Makefile
+++ b/OpenBSD/net/pounce-palaver/Makefile
@@ -16,7 +16,7 @@ PERMIT_PACKAGE =	Yes
 # uses pledge() and unveil()
 WANTLIB += c curl sqlite3 tls

-MASTER_SITES =		https://git.causal.agency/pounce/snapshot/
+SITES =		https://git.causal.agency/pounce/snapshot/

 # C11
 COMPILER =		base-clang ports-gcc
diff --git a/OpenBSD/net/pounce/Makefile b/OpenBSD/net/pounce/Makefile
index 7e69269..34c8628 100644
--- a/OpenBSD/net/pounce/Makefile
+++ b/OpenBSD/net/pounce/Makefile
@@ -14,7 +14,7 @@ PERMIT_PACKAGE =	Yes
 # uses pledge() and unveil()
 WANTLIB += c tls

-MASTER_SITES =		https://git.causal.agency/pounce/snapshot/
+SITES =		https://git.causal.agency/pounce/snapshot/

 # C11
 COMPILER =		base-clang ports-gcc
diff --git a/OpenBSD/sysutils/catsit/Makefile b/OpenBSD/sysutils/catsit/Makefile
index a26f6a8..eda5576 100644
--- a/OpenBSD/sysutils/catsit/Makefile
+++ b/OpenBSD/sysutils/catsit/Makefile
@@ -12,7 +12,7 @@ PERMIT_PACKAGE =	Yes
 # uses pledge() and unveil()
 WANTLIB =		c

-MASTER_SITES =		https://git.causal.agency/catsit/snapshot/
+SITES =		https://git.causal.agency/catsit/snapshot/

 # C11
 COMPILER =	base-clang ports-gcc
diff --git a/OpenBSD/www/cgit-pink/Makefile b/OpenBSD/www/cgit-pink/Makefile
index c547c07..1eb163b 100644
--- a/OpenBSD/www/cgit-pink/Makefile
+++ b/OpenBSD/www/cgit-pink/Makefile
@@ -5,11 +5,11 @@ COMMENT =	web frontend for git repositories
 DISTNAME =	cgit-pink-1.4.1
 CATEGORIES =	www devel

-DISTFILES =	${DISTNAME}.tar.gz:0 \
-		git-2.36.1.tar.gz:1
+DISTFILES =	${DISTNAME}.tar.gz
+DISTFILES.git = git-2.36.1.tar.gz

-MASTER_SITES0 =		https://git.causal.agency/cgit-pink/snapshot/
-MASTER_SITES1 =		https://www.kernel.org/pub/software/scm/git/
+SITES =		https://git.causal.agency/cgit-pink/snapshot/
+SITES.git =		https://www.kernel.org/pub/software/scm/git/
 HOMEPAGE =		https://git.causal.agency/cgit-pink/about/

 # GPLv2
--
2.44.0

From mboxrd@z Thu Jan  1 00:00:00 1970
Content-Type: text/plain;
	charset=us-ascii
Mime-Version: 1.0 (Mac OS X Mail 16.0 \(3774.300.61.1.2\))
Subject: Re: [PATCH] OpenBSD: switch ports MASTER_SITES=>SITES for 7.4
From: june <june@causal.agency>
In-Reply-To: <20240321023401.2431134-2-kusoneko@kusoneko.moe>
Date: Thu, 21 Mar 2024 21:26:45 -0400
Cc: list@causal.agency
Content-Transfer-Encoding: 7bit
Message-Id: <C45AA646-CE00-429F-B298-69F2E770993E@causal.agency>
References: <20240321023401.2431134-2-kusoneko@kusoneko.moe>
To: Kusoneko <kusoneko@kusoneko.moe>

> On Mar 20, 2024, at 22:34, Kusoneko <kusoneko@kusoneko.moe> wrote:
> 
> This changes all the OpenBSD ports to the new paradigm, allowing them to
> compile on OpenBSD 7.4+.
> 
> Note: some OpenBSD ports are not currently up to date with upstream:
> - cgit-pink uses git 2.36.1 when the latest git release is 2.44.0 as of now
> - litterbox is at version 1.8 instead of 1.9
> - pounce* are at version 3.0 instead of 3.1
> - offers catsit instead of kitd

thanks! I stopped using most of these port definitions since there
are now versions in the main ports tree. I should probably just
remove those from this repository.


